@@ -18,7 +18,7 @@
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-     $Id: cpp_example.cpp,v 1.18 2004/01/14 08:52:27 robert Exp $
+     $Id: cpp_example.cpp,v 1.19 2005/10/27 08:18:56 robert Exp $
 
 ----------------------------------------------------------------------------*/
 #include <stdio.h>
@@ -39,6 +39,10 @@ int main(void)
         o.SetServer(server, 80);
     }
 
+    // Check to see if the debug env var has been set 
+    if (getenv("MB_DEBUG"))
+        o.SetDebug(atoi(getenv("MB_DEBUG")));
+
     // If you need to use a proxy, uncomment/edit the following line
     // as appropriate
     //o.SetProxy("proxy.mydomain.com", 80);
