@@ -18,7 +18,7 @@
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-     $Id: mb_c.h,v 1.36 2003/10/16 22:21:10 robert Exp $
+     $Id: mb_c.h,v 1.37 2004/10/12 08:10:46 robert Exp $
 
 ----------------------------------------------------------------------------*/
 #ifndef _MB_C_H_
@@ -431,13 +431,13 @@ void      mb_GetFragmentFromURL(musicbrainz_t o, char *url, char *fragment,
 /**
  * Get the ordinal (list position) of an item in a list. This function is
  * normally used to retrieve the track number out of a list of tracks in
- * an album. A result list query (usually MBE_AlbumGetTrackList)
+ * an album using a list query (usually MBE_AlbumGetTrackList)
  * @see MBE_AlbumGetTrackList
  * @param o the musicbrainz_t object returned from mb_New()
- * @param list selector (usually MBE_AlbumGetTrackList)
+ * @param list type (usually MBE_AlbumGetTrackList)
  * @param URI of the item from the list to return.
  */
-int       mb_GetOrdinalFromList(musicbrainz_t o, char *resultList, char *URI);
+int       mb_GetOrdinalFromList(musicbrainz_t o, char *listType, char *URI);
 
 /**
  * This helper function calculates the crucial pieces of information for an MP3
