@@ -19,7 +19,7 @@
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-     $Id: http.cpp,v 1.24 2004/03/05 21:34:29 robert Exp $
+     $Id: http.cpp,v 1.25 2005/10/26 09:10:49 robert Exp $
 
 ----------------------------------------------------------------------------*/
 #include <stdio.h> 
@@ -366,13 +366,20 @@ Error MBHttp::Download(const string &url, const string &xml, bool fileDownload)
             if (xml.length())
                 strcat(query, xml.c_str());
 
-            int count;
-
-            err = Send(s, query, strlen(query), 0, count);
-            if (IsError(err))
-                result = kError_UserCancel; 
-            //count = send(s, query, strlen(query), 0);
-            if(count != (int)strlen(query))
+            int count, sent = 0;
+            int total = strlen(query);
+            while(total > 0)
+            {
+                err = Send(s, query + sent, strlen(query) - sent, 0, count);
+                if (IsError(err))
+                {
+                    result = kError_UserCancel; 
+                    break;
+                }
+                total -= count;
+                sent += count;
+            }
+            if (total != 0)
             {
                 result = kError_IOError;
             }
